summaryrefslogtreecommitdiff
path: root/uri
diff options
context:
space:
mode:
authordougm <dougm@13f79535-47bb-0310-9956-ffa450edef68>2001-08-19 16:00:21 +0000
committerdougm <dougm@13f79535-47bb-0310-9956-ffa450edef68>2001-08-19 16:00:21 +0000
commita179977ca371728b9a35f5176ba328a0a08c4ac7 (patch)
tree428aace64333c3f0c77e5c3b96fcf4727267b4e3 /uri
parentd1118ddca2730f857c45e93228aa5cc4514b5fcd (diff)
downloadlibapr-util-a179977ca371728b9a35f5176ba328a0a08c4ac7.tar.gz
renaming apr_uri_ api:
apr_uri_components -> apr_uri_t apr_uri_unparse_components -> apr_uri_unparse apr_uri_parse_components -> apr_uri_parse apr_uri_parse_hostinfo_components -> apr_uri_parse_hostinfo PR: Obtained from: Submitted by: Reviewed by: git-svn-id: http://svn.apache.org/repos/asf/apr/apr-util/trunk@58387 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'uri')
-rw-r--r--uri/apr_uri.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/uri/apr_uri.c b/uri/apr_uri.c
index 29bb66b8..7e181f11 100644
--- a/uri/apr_uri.c
+++ b/uri/apr_uri.c
@@ -119,11 +119,11 @@ APU_DECLARE(apr_port_t) apr_uri_default_port_for_scheme(const char *scheme_str)
return 0;
}
/* Unparse a apr_uri_components structure to an URI string.
* Optionally suppress the password for security reasons.
*/
-APU_DECLARE(char *) apr_uri_unparse_components(apr_pool_t *p,
- const apr_uri_components *uptr,
+APU_DECLARE(char *) apr_uri_unparse(apr_pool_t *p,
+ const apr_uri_t *uptr,
unsigned flags)
{
char *ret = "";
@@ -217,8 +217,8 @@ APU_DECLARE(char *) apr_uri_unparse_components(apr_pool_t *p,
* - fills in fields of uri_components *uptr
* - none on any of the r->* fields
*/
-APU_DECLARE(int) apr_uri_parse_components(apr_pool_t *p, const char *uri,
- apr_uri_components *uptr)
+APU_DECLARE(int) apr_uri_parse(apr_pool_t *p, const char *uri,
+ apr_uri_t *uptr)
{
const char *s;
const char *s1;
@@ -342,9 +342,9 @@ deal_with_host:
* currently at http://www.mcom.com/newsref/std/tunneling_ssl.html
* for the format of the "CONNECT host:port HTTP/1.0" request
*/
-APU_DECLARE(int) apr_uri_parse_hostinfo_components(apr_pool_t *p,
+APU_DECLARE(int) apr_uri_parse_hostinfo(apr_pool_t *p,
const char *hostinfo,
- apr_uri_components *uptr)
+ apr_uri_t *uptr)
{
const char *s;
char *endstr;
@@ -119,11 +119,11 @@ APU_DECLARE(apr_port_t) apr_uri_default_port_for_scheme(const char *scheme_str)
return 0;
}
-/* Unparse a apr_uri_components structure to an URI string.
+/* Unparse a apr_uri_t structure to an URI string.
* Optionally suppress the password for security reasons.
*/